@@ -121,6 +121,18 @@ class Getter:
             return None
         return body
 
+    def get_zip_csv_from_s3(self, file_name):
+        d = self.s3_client.get_object(Bucket="candas", Key=file_name)
+        import io
+
+        buffer = io.BytesIO(d["Body"].read())
+        import zipfile
+
+        z = zipfile.ZipFile(buffer)
+        body = z.open(z.namelist()[0]).read().decode("utf-8")
+        df = pd.read_csv(io.StringIO(body), low_memory=False)
+        return df
+
     def get_csv_from_s3(self, file_name):
         try:
             csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
@@ -183,6 +195,7 @@ def filter_dataset(
     is_historical="",
     n_periods="",
     mrq_notation=False,
+    unit_type="",
     warning=True,
 ):
 
@@ -218,6 +231,9 @@ def filter_dataset(
     if is_historical != "":
         df = df.loc[df["is_historical"] == is_historical]
 
+    if unit_type != "":
+        df = df.loc[df["unit_type"] == unit_type]
+
     if type(n_periods) is range:  # is this a range
         list_numbers = []
         list_numbers = list(n_periods)
@@ -534,13 +550,12 @@ def get_csin_from_ticker(ticker, auth_headers, mds_host=settings.MDS_HOST):
     return csin
 
 
-def get_excel_model(
-    ticker,
-    auth_headers,
-    default_dir=settings.DEFAULT_DIR,
-    mds_host=settings.MDS_HOST,
-    wp_host=settings.WP_HOST,
-):
+def get_excel_model(ticker, config):
+    auth_headers = get_api_headers(config.canalyst_api_key)
+    mds_host = config.mds_host
+    wp_host = config.wp_host
+    default_dir = config.default_dir
+
     csin = get_csin_from_ticker(ticker, auth_headers, mds_host)
 
     client = GraphqlClient(endpoint=f"{wp_host}/model-workbooks")
